﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using Infragistics.Controls.Schedules;
using System.Collections.ObjectModel;
using Infragistics;
using Infragistics.Controls.Schedules.Primitives;
using System.Threading;
using System.ComponentModel;

namespace ScheduleIssue
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window, INotifyPropertyChanged
    {
        #region INotifyPropertyChanged Implementation
        public event PropertyChangedEventHandler PropertyChanged;
        protected void OnPropertyChanged(string propertyName)
        {
            if (PropertyChanged != null)
                PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
        }
        protected void SetProperty<T>(ref T field, T value, string propertyName)
        {
            field = value;
            if (PropertyChanged != null)
                PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
        }
        #endregion

        private TimeSpan _VisibleStartTime;
        public TimeSpan VisibleStartTime { get { return _VisibleStartTime; } set { SetProperty(ref _VisibleStartTime, value, "VisibleStartTime"); } }

        private TimeSpan _VisibleEndTime;
        public TimeSpan VisibleEndTime { get { return _VisibleEndTime; } set { SetProperty(ref _VisibleEndTime, value, "VisibleEndTime"); } }

        public MainWindow()
        {
            InitializeComponent();
            this.DataContext = this;

            Thread.CurrentThread.CurrentCulture = new System.Globalization.CultureInfo("en-US");
            ObservableCollection<Resource> resources =
             new ObservableCollection<Resource>();
            Resource resAmanda = new Resource() { Id = "own1", Name = "Amanda" };
            Resource resClark = new Resource() { Id = "own2", Name = "Clark" };
            resources.Add(resAmanda);
            resources.Add(resClark);

            ObservableCollection<ResourceCalendar> calendars = new ObservableCollection<ResourceCalendar>();
            ResourceCalendar calAmanda = new ResourceCalendar()
            {
                Id = "cal1",
                OwningResourceId = "own1"
            };
            calendars.Add(calAmanda); 
            ResourceCalendar calClark = new ResourceCalendar()
            {
                Id = "cal1",
                OwningResourceId = "own2"
            };
            calendars.Add(calClark);

            ObservableCollection<Appointment> appointments = new ObservableCollection<Appointment>();
            Appointment app1 = new Appointment()
            {
                Id = "t1",
                OwningResourceId = "own1",
                OwningCalendarId = "cal1",
                Subject = "Appointment 1",
                Description = "My first appointment",
                // Convert the date to universal time, because a time zone is not set
                // in this snippet    
                Start = DateTime.Today.AddHours(9).AddMinutes(12).ToUniversalTime(),
                End = DateTime.Today.AddHours(11).AddMinutes(42).ToUniversalTime()
            };
            appointments.Add(app1);

            Appointment app2 = new Appointment()
            {
                Id = "t2",
                OwningResourceId = "own2",
                OwningCalendarId = "cal1",
                Subject = "Appointment 2",
                Description = "My second appointment",
                // Convert the date to universal time, because a time zone is not set
                // in this snippet    
                Start = DateTime.Today.AddHours(10).AddMinutes(12).ToUniversalTime(),
                End = DateTime.Today.AddHours(11).AddMinutes(42).ToUniversalTime()
            };
            appointments.Add(app2);

            ListScheduleDataConnector dataConnector = new ListScheduleDataConnector();
            dataConnector.ResourceItemsSource = resources;
            dataConnector.ResourceCalendarItemsSource = calendars;
            dataConnector.AppointmentItemsSource = appointments;

            XamScheduleDataManager dataManager = new XamScheduleDataManager();
            dataManager.DataConnector = dataConnector;
            CalendarGroupCollection calGroups = dataManager.CalendarGroups;
            CalendarGroup calGroup = new CalendarGroup();

            calGroup.InitialCalendarIds = "own2[cal1]";
            calGroups.Add(calGroup);

            this.dayView.DataManager = dataManager;
        }
    }
}
