﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows.Interactivity;
using Infragistics.Controls.Schedules;
using System.Windows.Controls.Primitives;
using System.Windows;
using System.Windows.Threading;

namespace ScheduleIssue
{
    public class VisibleTimesBehavior : Behavior<XamDayView>
    {
        public TimeSpan Top
        {
            get { return (TimeSpan)GetValue(TopProperty); }
            set { SetValue(TopProperty, value); }
        }

        // Using a DependencyProperty as the backing store for Top.  This enables animation, styling, binding, etc...
        public static readonly DependencyProperty TopProperty =
            DependencyProperty.Register("Top", typeof(TimeSpan), typeof(VisibleTimesBehavior), new UIPropertyMetadata(TimeSpan.Zero));


        public TimeSpan Bottom
        {
            get { return (TimeSpan)GetValue(BottomProperty); }
            set { SetValue(BottomProperty, value); }
        }

        // Using a DependencyProperty as the backing store for Bottom.  This enables animation, styling, binding, etc...
        public static readonly DependencyProperty BottomProperty =
            DependencyProperty.Register("Bottom", typeof(TimeSpan), typeof(VisibleTimesBehavior), new UIPropertyMetadata(TimeSpan.Zero));

        
        protected override void OnAttached()
        {
            base.OnAttached();

            Application.Current.Dispatcher.BeginInvoke(new Action(() =>
            {
                var scrollBar = (ScrollBar)Infragistics.Windows.Utilities.GetDescendantFromName(AssociatedObject, "TimeslotScrollBar");
                if (scrollBar != null)
                {
                    scrollBar.Scroll += scrollBar_Scroll;

                    CalculateTimes(scrollBar, AssociatedObject.TimeslotInterval.TotalHours);
                }
            }), DispatcherPriority.ContextIdle, null);
        }

        void scrollBar_Scroll(object sender, ScrollEventArgs e)
        {
            CalculateTimes(sender as ScrollBar, AssociatedObject.TimeslotInterval.TotalHours);
        }

        private void CalculateTimes(ScrollBar sb, double interval)
        {
            double p = sb.Value / sb.Maximum;
            double startHour = (24.0 - (sb.LargeChange * interval)) * p;
            double endHour = startHour + (sb.LargeChange * interval);

            Top = TimeSpan.FromHours(startHour);
            Bottom = TimeSpan.FromHours(endHour);
        }
    }
}
